<?php

function admin_style() {
    wp_enqueue_style('admin-theme', get_template_directory_uri() . "/library/css/admin-style.css", false, "1.0", "all");
}

add_action('admin_enqueue_scripts', 'admin_style');


/* * *********** DASHBOARD WIDGETS **************** */

// disable default dashboard widgets
function disable_default_dashboard_widgets() {
    global $wp_meta_boxes;
    // unset($wp_meta_boxes['dashboard']['normal']['core']['dashboard_right_now']);    // Right Now Widget
    unset($wp_meta_boxes['dashboard']['normal']['core']['dashboard_activity']);        // Activity Widget
    unset($wp_meta_boxes['dashboard']['normal']['core']['dashboard_recent_comments']); // Comments Widget
    unset($wp_meta_boxes['dashboard']['normal']['core']['dashboard_incoming_links']);  // Incoming Links Widget
    unset($wp_meta_boxes['dashboard']['normal']['core']['dashboard_plugins']);         // Plugins Widget
    // unset($wp_meta_boxes['dashboard']['side']['core']['dashboard_quick_press']);    // Quick Press Widget
    unset($wp_meta_boxes['dashboard']['side']['core']['dashboard_recent_drafts']);     // Recent Drafts Widget
    unset($wp_meta_boxes['dashboard']['side']['core']['dashboard_primary']);           //
    unset($wp_meta_boxes['dashboard']['side']['core']['dashboard_secondary']);         //
    // remove plugin dashboard boxes
    unset($wp_meta_boxes['dashboard']['normal']['core']['yoast_db_widget']);           // Yoast's SEO Plugin Widget
    unset($wp_meta_boxes['dashboard']['normal']['core']['rg_forms_dashboard']);        // Gravity Forms Plugin Widget
    unset($wp_meta_boxes['dashboard']['normal']['core']['bbp-dashboard-right-now']);   // bbPress Plugin Widget
}

add_action('wp_dashboard_setup', 'disable_default_dashboard_widgets');

/* * *********** CUSTOM LOGIN PAGE **************** */

function bones_login_css() {
    wp_enqueue_style('bones_login_css', get_template_directory_uri() . '/library/css/login.css', false);
}

// changing the logo link from wordpress.org to your site
function bones_login_url() {
    return home_url();
}

// changing the alt text on the logo to show your site name
function bones_login_title() {
    return get_option('blogname');
}

// calling it only on the login page
add_action('login_enqueue_scripts', 'bones_login_css', 10);
add_filter('login_headerurl', 'bones_login_url');
add_filter('login_headertitle', 'bones_login_title');


/* * *********** CUSTOMIZE ADMIN ****************** */

/*
  I don't really recommend editing the admin too much
  as things may get funky if WordPress updates. Here
  are a few funtions which you can choose to use if
  you like.
 */

// Custom Backend Footer
function bones_custom_admin_footer() {
    _e('Project Manager &copy; 2015', 'bonestheme');
}

add_filter('admin_footer_text', 'bones_custom_admin_footer');



/* * *********** CUSTOM COLUMN TICKET AND PROJECT **************** */

function tickets_list_columns($columns) {
    $columns = array(
        'cb' => '<input type="checkbox" />',
        'title' => 'Titre',
        'ticket_date_buttoire' => 'Date buttoire',
        'taxonomy-priorite' => 'Priorité',
        'taxonomy-status' => 'Status',
        'ticket_temps_devise' => 'Temps devisé',
        'ticket_temps_passe' => 'Temps passé'
    );
    return $columns;
}

function projets_list_columns($columns) {
    $columns = array(
        'cb' => '<input type="checkbox" />',
        'title' => 'Titre',
        'projet_date_debut' => 'Date début',
        'projet_date_fin' => 'Date fin',
        'projet_date_fin_reelle' => 'Date fin (réelle)',
        'taxonomy-status-projet' => 'Status',
        'taxonomy-cms-projet' => 'CMS',
        'projet_pourcentage_de_dev' => '% dev.'
    );
    return $columns;
}

function add_list_columns($column) {
    global $post;
    // ticket
    if ($column == 'ticket_date_buttoire') {
        if (get_field('ticket_date_buttoire')) {
            echo get_field('ticket_date_buttoire');
        }
    }
    if ($column == 'ticket_temps_devise') {
        if (get_field('ticket_temps_devise')) {
            echo get_field('ticket_temps_devise');
        }
    }
    if ($column == 'ticket_temps_passe') {
        if (get_field('ticket_temps_passe')) {
            echo get_field('ticket_temps_passe');
        }
    }

    //projet
    elseif ($column == 'projet_date_debut') {
        if (get_field('projet_date_debut')) {
            echo get_field('projet_date_debut');
        }
    } elseif ($column == 'projet_date_fin') {
        if (get_field('projet_date_fin')) {
            echo get_field('projet_date_fin');
        }
    } elseif ($column == 'projet_date_fin_reelle') {
        if (get_field('projet_date_fin_reelle')) {
            echo get_field('projet_date_fin_reelle');
        }
    } elseif ($column == 'projet_pourcentage_de_dev') {
        if (get_field('projet_pourcentage_de_dev')) {
            echo get_field('projet_pourcentage_de_dev');
        }
    }
}

add_action("manage_posts_custom_column", "add_list_columns");
add_filter("manage_edit-ticket_columns", "tickets_list_columns");
add_filter("manage_edit-projet_columns", "projets_list_columns");

// ORDER BY DUE DATE
function my_pre_get_posts($query) {
    if (isset($query->query_vars['post_type']) && $query->query_vars['post_type'] == 'projet') {
        $query->set('orderby', 'meta_value');
        $query->set('meta_key', 'projet_date_fin');
        $query->set('order', 'DESC');
    }
    return $query;
}

add_action('pre_get_posts', 'my_pre_get_posts');


/* * *********** CUSTOM FILTER TICKET AND PROJECT **************** */

function my_column_register_sortable($columns) {
    $columns['ticket_date_buttoire'] = 'ticket_date_buttoire';
    return $columns;
}

add_filter("manage_edit-posts_sortable_columns", "my_column_register_sortable");
?>
