<?php

function bones_head_cleanup() {
    remove_action('wp_head', 'rsd_link');
    remove_action('wp_head', 'wlwmanifest_link');
    remove_action('wp_head', 'parent_post_rel_link', 10, 0);
    remove_action('wp_head', 'start_post_rel_link', 10, 0);
    remove_action('wp_head', 'adjacent_posts_rel_link_wp_head', 10, 0);
    remove_action('wp_head', 'wp_generator');
    add_filter('style_loader_src', 'bones_remove_wp_ver_css_js', 9999);
    add_filter('script_loader_src', 'bones_remove_wp_ver_css_js', 9999);
}

function rw_title($title, $sep, $seplocation) {
    global $page, $paged;
    if (is_feed())
        return $title;
    if ('right' == $seplocation) {
        $title .= get_bloginfo('name');
    } else {
        $title = get_bloginfo('name') . $title;
    }
    $site_description = get_bloginfo('description', 'display');

    if ($site_description && ( is_home() || is_front_page() )) {
        $title .= " {$sep} {$site_description}";
    }
    if ($paged >= 2 || $page >= 2) {
        $title .= " {$sep} " . sprintf(__('Page %s', 'dbt'), max($paged, $page));
    }
    return $title;
}

function bones_rss_version() {
    return '';
}

function bones_remove_wp_ver_css_js($src) {
    if (strpos($src, 'ver='))
        $src = remove_query_arg('ver', $src);
    return $src;
}

function bones_remove_wp_widget_recent_comments_style() {
    if (has_filter('wp_head', 'wp_widget_recent_comments_style')) {
        remove_filter('wp_head', 'wp_widget_recent_comments_style');
    }
}

function bones_remove_recent_comments_style() {
    global $wp_widget_factory;
    if (isset($wp_widget_factory->widgets['WP_Widget_Recent_Comments'])) {
        remove_action('wp_head', array($wp_widget_factory->widgets['WP_Widget_Recent_Comments'], 'recent_comments_style'));
    }
}

function bones_gallery_style($css) {
    return preg_replace("!<style type='text/css'>(.*?)</style>!s", '', $css);
}

/* * *******************
  SCRIPTS & ENQUEUEING
 * ******************* */

// loading modernizr and jquery, and reply script
function bones_scripts_and_styles() {

    global $wp_styles; // call global $wp_styles variable to add conditional wrapper around ie stylesheet the WordPress way

    if (!is_admin()) {
        wp_deregister_script('jquery');
        wp_register_script('jquery', 'http://code.jquery.com/jquery-2.1.4.min.js', array(), '2.5.3', false);
        wp_enqueue_script('jquery');

        wp_enqueue_style('bones-bootstrap', 'https://maxcdn.bootstrapcdn.com/bootstrap/3.3.4/css/bootstrap.min.css');
        wp_enqueue_style('bones-fontawesome', 'https://maxcdn.bootstrapcdn.com/font-awesome/4.3.0/css/font-awesome.min.css', array(), '4.3.0', false);

        // MAIN STYLE.CSS
        wp_enqueue_style('bones-stylesheet', get_stylesheet_directory_uri() . '/library/css/style.css', array(), '1.1.6', 'all');
        wp_enqueue_style('bones-ie-css', get_stylesheet_directory_uri() . '/library/css/ie.css', array(), '');
        $wp_styles->add_data('bones-ie-css', 'conditional', 'lt IE 9');
        
        wp_enqueue_style('fancybox-css', get_stylesheet_directory_uri() . '/library/js/jquery.fancybox.css', array(), '');
        wp_enqueue_script('fancybox-js', get_stylesheet_directory_uri() . '/library/js/jquery.fancybox.js', array(), '', true);

        /* ===================================
          SCRIPTS
          =================================== */
        wp_enqueue_script('bones-modernizr', get_stylesheet_directory_uri() . '/library/js/libs/modernizr.custom.min.js', array(), '2.5.3', false);
        wp_enqueue_script('bones-ie-respond', get_stylesheet_directory_uri() . '/library/js/libs/vendor.js', array('jquery'), '', false);
        
        wp_enqueue_script('bones-js', get_stylesheet_directory_uri() . '/library/js/scripts.js', array('jquery'), '', true);
    }
}

/* * *******************
  THEME SUPPORT
 * ******************* */

// Adding WP 3+ Functions & Theme Support
function bones_theme_support() {

    // wp thumbnails (sizes handled in functions.php)
    add_theme_support('post-thumbnails');

    // default thumb size
    set_post_thumbnail_size(125, 125, true);

    // wp custom background (thx to @bransonwerner for update)
    add_theme_support('custom-background', array(
        'default-image' => '', // background image default
        'default-color' => '', // background color default (dont add the #)
        'wp-head-callback' => '_custom_background_cb',
        'admin-head-callback' => '',
        'admin-preview-callback' => ''
            )
    );

    // rss thingy
    add_theme_support('automatic-feed-links');

    // to add header image support go here: http://themble.com/support/adding-header-background-image-support/
    // adding post format support
    add_theme_support('post-formats', array(
        'aside', // title less blurb
        'gallery', // gallery of images
        'link', // quick link to other site
        'image', // an image
        'quote', // a quick quote
        'status', // a Facebook like status update
        'video', // video
        'audio', // audio
        'chat'               // chat transcript
            )
    );

    // wp menus
    add_theme_support('menus');

    // registering wp3+ menus
    register_nav_menus(
            array(
                'main-nav' => __('The Main Menu', 'bonestheme'), // main nav in header
                'footer-links' => __('Footer Links', 'bonestheme') // secondary nav in footer
            )
    );

    // Enable support for HTML5 markup.
    add_theme_support('html5', array(
        'comment-list',
        'search-form',
        'comment-form'
    ));
}

/* end bones theme support */


/* * *******************
  RELATED POSTS FUNCTION
 * ******************* */

// Related Posts Function (call using bones_related_posts(); )
function bones_related_posts() {
    echo '<ul id="bones-related-posts">';
    global $post;
    $tags = wp_get_post_tags($post->ID);
    if ($tags) {
        foreach ($tags as $tag) {
            $tag_arr .= $tag->slug . ',';
        }
        $args = array(
            'tag' => $tag_arr,
            'numberposts' => 5, /* you can change this to show more */
            'post__not_in' => array($post->ID)
        );
        $related_posts = get_posts($args);
        if ($related_posts) {
            foreach ($related_posts as $post) : setup_postdata($post);
                ?>
                <li class="related_post"><a class="entry-unrelated" href="<?php the_permalink() ?>" title="<?php the_title_attribute(); ?>"><?php the_title(); ?></a></li>
                <?php
            endforeach;
        }
        else {
            ?>
            <?php echo '<li class="no_related_post">' . __('No Related Posts Yet!', 'bonestheme') . '</li>'; ?>
            <?php
        }
    }
    wp_reset_postdata();
    echo '</ul>';
}

/* end bones related posts function */

/* * *******************
  PAGE NAVI
 * ******************* */

// Numeric Page Navi (built into the theme by default)
function bones_page_navi() {
    global $wp_query;
    $bignum = 999999999;
    if ($wp_query->max_num_pages <= 1)
        return;
    echo '<nav class="pagination">';
    echo paginate_links(array(
        'base' => str_replace($bignum, '%#%', esc_url(get_pagenum_link($bignum))),
        'format' => '',
        'current' => max(1, get_query_var('paged')),
        'total' => $wp_query->max_num_pages,
        'prev_text' => '&larr;',
        'next_text' => '&rarr;',
        'type' => 'list',
        'end_size' => 3,
        'mid_size' => 3
    ));
    echo '</nav>';
}

/* end page navi */

/* * *******************
  RANDOM CLEANUP ITEMS
 * ******************* */

// remove the p from around imgs (http://css-tricks.com/snippets/wordpress/remove-paragraph-tags-from-around-images/)
function bones_filter_ptags_on_images($content) {
    return preg_replace('/<p>\s*(<a .*>)?\s*(<img .* \/>)\s*(<\/a>)?\s*<\/p>/iU', '\1\2\3', $content);
}

// This removes the annoying […] to a Read More link
function bones_excerpt_more($more) {
    global $post;
    // edit here if you like
    return '...  <a class="excerpt-read-more" href="' . get_permalink($post->ID) . '" title="' . __('Read ', 'bonestheme') . esc_attr(get_the_title($post->ID)) . '">' . __('Read more &raquo;', 'bonestheme') . '</a>';
}
?>
